from abc import ABCMeta, abstractmethod
from collections import namedtuple

from six import add_metaclass


class Tag(
    namedtuple('Tag', [
      'name', 'image', 'reversion', 'lifetime_start_ts', 'lifetime_end_ts', 'manifest_list',
      'docker_image_id'
    ])):
  """
  Tag represents a name to an image.
  :type name: string
  :type image: Image
  :type reversion: boolean
  :type lifetime_start_ts: int
  :type lifetime_end_ts: int
  :type manifest_list: [manifest_digest]
  :type docker_image_id: string
  """


class RepositoryTagHistory(namedtuple('RepositoryTagHistory', ['tags', 'more'])):
  """
  Tag represents a name to an image.
  :type tags: [Tag]
  :type more: boolean
  """


@add_metaclass(ABCMeta)
class TagDataInterface(object):
  """
  Interface that represents all data store interactions required by a Tag.
  """

  @abstractmethod
  def list_repository_tag_history(self, namespace_name, repository_name, page=1, size=100,
                                  specific_tag=None):
    """
    Returns a RepositoryTagHistory with a list of historic tags and whether there are more tags then returned.
    """
