from data import model
from endpoints.api.tag_models_interface import TagDataInterface, Tag, RepositoryTagHistory


class PreOCIModel(TagDataInterface):
  """
  PreOCIModel implements the data model for the Tags using a database schema
  before it was changed to support the OCI specification.
  """

  def list_repository_tag_history(self, namespace_name, repository_name, page=1, size=100,
                                  specific_tag=None):
    repository = model.repository.get_repository(namespace_name, repository_name)
    if repository is None:
      return None
    tags, manifest_map, more = model.tag.list_repository_tag_history(repository, page, size,
                                                                     specific_tag)
    repository_tag_history = []
    for tag in tags:
      manifest_list = None
      if tag.id in manifest_map:
        manifest_list = manifest_map[tag.id]
      repository_tag_history.append(
        Tag(name=tag.name, image=tag.image, reversion=tag.reversion,
            lifetime_start_ts=tag.lifetime_start_ts, lifetime_end_ts=tag.lifetime_end_ts,
            manifest_list=manifest_list, docker_image_id=tag.image.docker_image_id))
    return RepositoryTagHistory(tags=repository_tag_history, more=more)


pre_oci_model = PreOCIModel()
